@@ -34,6 +34,7 @@
 #include <stdlib.h>	/* atoi() */
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <ctype.h> /* tolower() */
 
 #include "gnome-i18nP.h"
 #include "gnome-util.h"
@@ -505,10 +506,10 @@ access_config (access_type mode, const char *section_name,
 	return def;
 }
 
-/* an extended version of access_config for looking up values in ~/.gnome2.
+/* an extended version of access_config for looking up values in ~/.gnome.
  * For writes it falls through to the standard behaviour.
  * For lookups, it first checks for the value in
- * $(datadir)/gnome/config-override, and if it isn't there in ~/.gnome2,
+ * $(datadir)/gnome/config-override, and if it isn't there in ~/.gnome,
  * then checks $(datadir)/gnome/config, and as a last fallback uses def.
  * This gives system administrators high level control over the default
  * configuration values for GNOME
@@ -656,9 +657,10 @@ static gint
 check_path(char *path, mode_t newmode)
 {
 	gchar *dirpath;
-	gchar *p, *cur;
+	gchar *p;
 	GString *newpath;
 	struct stat s;
+	char *tokp;
 
 	g_return_val_if_fail (path != NULL, FALSE);
 
@@ -694,15 +696,9 @@ check_path(char *path, mode_t newmode)
 	while(*p == '/')
 		p++;
 
-	cur = p;
+	p = strtok_r(p, "/", &tokp);
 	newpath = g_string_new("");
-	while ((p = cur)) {
-	       	cur = strchr (cur, '/');
-		if (cur) {
-			*cur = '\0';
-			cur++;
-		}
-		
+	do {
 		newpath = g_string_append_c(newpath,'/');
 		newpath = g_string_append(newpath,p);
 		if(stat(newpath->str,&s)==0) {
@@ -720,7 +716,8 @@ check_path(char *path, mode_t newmode)
 				return FALSE;
 			}
 		}
-	}
+
+	} while ((p = strtok_r(NULL, "/", &tokp)) != NULL);
 
 	g_string_free(newpath,TRUE);
 
@@ -791,10 +788,10 @@ dump_profile (TProfile *p, gboolean one_only)
  * Writes all of the information modified by gnome-config to the
  * disk.
  *
- * Note: the gnome-config code does not write anything to the
+ * Note: the gnome_config code does not write anything to the
  * configuration files until this routine is actually invoked.
  *
- * Returns: %TRUE if everything went well. %FALSE if any file
+ * Returns: %TRUE if everything went well.  %FALSE if any file
  * could not be written to disk.
  */
 gboolean 
@@ -813,13 +810,9 @@ gnome_config_sync (void)
  * Writes all of the information modified by gnome-config to the
  * disk for the given file.
  *
- * Note: the gnome-config code does not write anything to the
- * configuration files until this routine or gnome_config_sync()
+ * Note: the gnome_config code does not write anything to the
+ * configuration files until this routine or gnome_config_sync 
  * is actually invoked.
- *
- * Returns: %TRUE if everything went well, %FALSE if the file
- * could not be written to for some reason.  %FALSE is only returned
- * when a write was actually attempted and failed.
  */
 /**
  * gnome_config_private_sync_file:
@@ -828,8 +821,8 @@ gnome_config_sync (void)
  * Writes all of the information modified by gnome-config to the
  * disk for the given private file.
  *
- * Note: the gnome-config code does not write anything to the
- * configuration files until this routine or gnome_config_sync()
+ * Note: the gnome_config code does not write anything to the
+ * configuration files until this routine or gnome_config_sync 
  * is actually invoked.
  *
  * Returns: %TRUE if everything went well, %FALSE if the file
@@ -837,7 +830,7 @@ gnome_config_sync (void)
  * when a write was actually attempted and failed.
  */
 gboolean 
-gnome_config_sync_file_ (char *path, gboolean priv)
+_gnome_config_sync_file (char *path, gboolean priv)
 {
 	gboolean ret = TRUE;
 	TProfile *p;
@@ -873,7 +866,7 @@ gnome_config_sync_file_ (char *path, gboolean priv)
  * Cleans up the configuration file specified by @path from any
  * configuration information.
  *
- * Changes will take place after gnome_config_sync() has been invoked.
+ * Changes will take place after #gnome_config_sync has been invoked.
  */
 /**
  * gnome_config_private_clean_file:
@@ -882,10 +875,10 @@ gnome_config_sync_file_ (char *path, gboolean priv)
  * Cleans up the private configuration file specified by @path from
  * any configuration information.
  *
- * Changes will take place after gnome_config_sync() has been invoked.
+ * Changes will take place after #gnome_config_sync has been invoked.
  */
 void 
-gnome_config_clean_file_ (const char *path, gboolean priv)
+_gnome_config_clean_file (const char *path, gboolean priv)
 {
 	TProfile *p;
 	ParsedPath *pp;
@@ -920,7 +913,7 @@ gnome_config_clean_file_ (const char *path, gboolean priv)
  *
  * Releases any memory resources that were allocated from accessing
  * the configuration file in @path.  Changes will take place after
- * gnome_config_sync() has been invoked
+ * #gnome_config_sync has been invoked
  */
 /**
  * gnome_config_private_drop_file:
@@ -930,7 +923,7 @@ gnome_config_clean_file_ (const char *path, gboolean priv)
  * private configuration file in @path.
  */
 void 
-gnome_config_drop_file_ (const char *path, gboolean priv)
+_gnome_config_drop_file (const char *path, gboolean priv)
 {
 	TProfile *p;
 	TProfile *last;
@@ -971,9 +964,9 @@ gnome_config_drop_file_ (const char *path, gboolean priv)
  * Creates an iterator handle that can be used to
  * iterate over the keys in a section in a gnome configuration
  * file.  @path must refer to a section.  The returned value
- * can be used as an iterator for gnome_config_iterator_next().
+ * can be used as an iterator for #gnome_config_iterator_next().
  *
- * Returns: The iterator handle.
+ * Returns the iterator handle.
  */
 /**
  * gnome_config_private_init_iterator:
@@ -982,12 +975,12 @@ gnome_config_drop_file_ (const char *path, gboolean priv)
  * Creates an iterator handle that can be used to
  * iterate over the keys in a section in a private gnome configuration
  * file.  @path must refer to a section.  The returned value
- * can be used as an iterator for gnome_config_iterator_next().
+ * can be used as an iterator for #gnome_config_iterator_next().
  *
- * Returns: The iterator handle.
+ * Returns the iterator handle.
  */
 void *
-gnome_config_init_iterator_ (const char *path, gboolean priv)
+_gnome_config_init_iterator (const char *path, gboolean priv)
 {
 	TProfile   *New;
 	TSecHeader *section;
@@ -1040,9 +1033,9 @@ gnome_config_init_iterator_ (const char *path, gboolean priv)
  * Creates an iterator handle that can be used to iterate over the
  * sections in a gnome configuration file.  @path must refer to a
  * gnome configuration file.  The returned value can be used as an
- * iterator for gnome_config_iterator_next().
+ * iterator for #gnome_config_iterator_next().
  *
- * Returns: The iterator handle.
+ * Returns the iterator handle.
  */
 /**
  * gnome_config_private_init_iterator_sections:
@@ -1051,12 +1044,12 @@ gnome_config_init_iterator_ (const char *path, gboolean priv)
  * Creates an iterator handle that can be used to iterate over the
  * sections in a private gnome configuration file.  @path must refer to a
  * gnome configuration file.  The returned value can be used as an
- * iterator for gnome_config_iterator_next().
+ * iterator for #gnome_config_iterator_next().
  *
- * Returns: The iterator handle.
+ * Returns the iterator handle.
  */
 void *
-gnome_config_init_iterator_sections_ (const char *path, gboolean priv)
+_gnome_config_init_iterator_sections (const char *path, gboolean priv)
 {
 	TProfile   *New;
 	TSecHeader *section;
@@ -1101,11 +1094,15 @@ gnome_config_init_iterator_sections_ (const char *path, gboolean priv)
  * @key:   Address where the key gets stored.
  * @value: Address where the value gets stored.
  *
+ *
+ * Returns a new iterator handle.
+ *
  * If @key is non-NULL, then @key will point to a g_malloc()ed region that
  * holds the key.
  *
  * If @value is non-NULL, then @value will point to a g_malloc()ed region that
  * holds the key.
+ *
  */
 void *
 gnome_config_iterator_next (void *iterator_handle, char **key, char **value)
@@ -1159,22 +1156,22 @@ gnome_config_iterator_next (void *iterator_handle, char **key, char **value)
 
 /**
  * gnome_config_clean_section:
- * @path: A gnome configuration path to a section.
+ * @path: a gnome configuration path to a section.
  *
  * Cleans up the section specified by @path from any
  * configuration information.  Changes will only take place
- * after gnome_config_sync() has been invoked.
+ * after #gnome_config_sync has been invoked.
  */
 /**
  * gnome_config_private_clean_section:
- * @path: A gnome configuration path to a section.
+ * @path: a gnome configuration path to a section.
  *
  * Cleans up the section specified by @path in a private file from any
  * configuration information.  Changes will only take place after
- * gnome_config_sync() has been invoked.
+ * #gnome_config_sync has been invoked.
  */
 void 
-gnome_config_clean_section_ (const char *path, gboolean priv)
+_gnome_config_clean_section (const char *path, gboolean priv)
 {
 	TProfile   *New;
 	TSecHeader *section;
@@ -1217,23 +1214,23 @@ gnome_config_clean_section_ (const char *path, gboolean priv)
 
 /**
  * gnome_config_clean_key:
- * @path: A gnome configuration path to a key.
+ * @path: a gnome configuration path to a key.
  *
  * Removes the definition for the key on a gnome configuration file.
  *
- * Changes will take place after gnome_config_sync() has been invoked.
+ * Changes will take place after #gnome_config_sync has been invoked.
  */
 /**
  * gnome_config_private_clean_key:
- * @path: A gnome configuration path to a key.
+ * @path: a gnome configuration path to a key.
  *
  * Removes the definition for the key on a private gnome configuration
  * file.
  *
- * Changes will take place after gnome_config_sync() has been invoked.
+ * Changes will take place after #gnome_config_sync has been invoked.
  */
 void 
-gnome_config_clean_key_ (const char *path, gboolean priv)
+_gnome_config_clean_key (const char *path, gboolean priv)
 	/* *section_name, char *file */
 {
 	TProfile   *New;
@@ -1281,7 +1278,7 @@ gnome_config_clean_key_ (const char *path, gboolean priv)
  * Queries the gnome configuration file for the presence
  * of the section specified in @path.
  *
- * Returns: %TRUE if the section exists, %FALSE otherwise.
+ * Returns TRUE if the section exists.  FALSE otherwise.
  */
 /**
  * gnome_config_private_has_section:
@@ -1290,10 +1287,10 @@ gnome_config_clean_key_ (const char *path, gboolean priv)
  * Queries the private gnome configuration file for the presence
  * of the section specified in @path.
  *
- * Returns: %TRUE if the section exists, %FALSE otherwise.
+ * Returns TRUE if the section exists.  FALSE otherwise.
  */
 gboolean 
-gnome_config_has_section_ (const char *path, gboolean priv)
+_gnome_config_has_section (const char *path, gboolean priv)
 	/* char *section_name, char *profile */
 {
 	TProfile   *New;
@@ -1337,7 +1334,7 @@ gnome_config_has_section_ (const char *path, gboolean priv)
  * gnome_config_drop_all:
  *
  * Drops any information cached in memory that was fetched with
- * gnome config. Any pending information that has not been
+ * gnome config.  Any pending information that has not been
  * written to disk is discarded.
  */
 void 
@@ -1352,18 +1349,14 @@ gnome_config_drop_all (void)
  * gnome_config_get_int:
  * @path: A gnome configuration path to an item.
  *
- * Retrieves an integer value configuration item.
- *
- * Returns: The value of a configuration item.
+ * Retrieves & returns the value of a configuration item as an integer.
  */
 /**
  * gnome_config_private_get_int:
  * @path: A gnome configuration path to an item in the user-private namespace.
  *
- * Retrieves a configuration item as an int from the user's private
- * configuration storage area.
- *
- * Returns: The value of a configuration item as an integer.
+ * Retrieves & returns the value of a configuration item as an integer.
+ * The item is retrieved from the user's private configuration storage area.
  */
 /**
  * gnome_config_get_int_with_default:
@@ -1371,10 +1364,7 @@ gnome_config_drop_all (void)
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Retrieves an integer value configuration item.
- *
- * Returns: The value of a configuration item as an integer or @def if the
- * configuration item does not exist.
+ * Retrieves & returns the value of a configuration item as an integer.
  */
 /**
  * gnome_config_private_get_int_with_default:
@@ -1382,14 +1372,11 @@ gnome_config_drop_all (void)
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Retrieves a configuration item as an int from the user's private
- * configuration storage area.
- *
- * Returns: The value of a configuration item as an integer or @def if the
- * configuration item does not exist.
+ * Retrieves & returns the value of a configuration item as an integer.
+ * The item is retrieved from the user's private configuration storage area.
  */
 gint
-gnome_config_get_int_with_default_ (const char *path, gboolean *def, gboolean priv)
+_gnome_config_get_int_with_default (const char *path, gboolean *def, gboolean priv)
 {
 	ParsedPath *pp;
 	const char *r;
@@ -1419,19 +1406,15 @@ gnome_config_get_int_with_default_ (const char *path, gboolean *def, gboolean pr
  * gnome_config_get_float:
  * @path: A gnome configuration path to an item.
  *
- * Retrieves a floating-point valued configuration item.
- *
- * Returns: The value of a configuration item.
+ * Retrieves & returns the value of a configuration item as a floating-point
+ * number.
  */
 /**
  * gnome_config_private_get_float:
  * @path: A gnome configuration path to an item in the user-private namespace.
  *
- * Retrieves a configuration item from the user's private configuration storage
- * area.
- *
- * Returns: The value of a configuration item as a floating-point
- * number.
+ * Retrieves & returns the value of a configuration item as a floating-point number.
+ * The item is retrieved from the user's private configuration storage area.
  */
 /**
  * gnome_config_get_float_with_default:
@@ -1439,10 +1422,7 @@ gnome_config_get_int_with_default_ (const char *path, gboolean *def, gboolean pr
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Retrieves a floating-point valued configuration item.
- *
- * Returns: The value of a configuration item as a floating-point
- * number or @def if the configuration item does not exist.
+ * Retrieves & returns the value of a configuration item as a floating-point number.
  */
 /**
  * gnome_config_private_get_float_with_default:
@@ -1450,14 +1430,11 @@ gnome_config_get_int_with_default_ (const char *path, gboolean *def, gboolean pr
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Retrieves a configuration item from the user's private configuration storage
- * area.
- *
- * Returns: The value of a configuration item as a floating-point
- * number or @def if the configuration item does not exist.
+ * Retrieves & returns the value of a configuration item as a floating-point number.
+ * The item is retrieved from the user's private configuration storage area.
  */
 gdouble
-gnome_config_get_float_with_default_ (const char *path, gboolean *def, gboolean priv)
+_gnome_config_get_float_with_default (const char *path, gboolean *def, gboolean priv)
 {
 	ParsedPath *pp;
 	const char *r;
@@ -1487,7 +1464,7 @@ gnome_config_get_float_with_default_ (const char *path, gboolean *def, gboolean
 }
 
 /*
- * same as gnome_config_get_string_with_default_, but using (ParsedPath *)
+ * same as _gnome_config_get_string_with_default, but using (ParsedPath *)
  */
 static char *
 get_string_with_default_from_pp (ParsedPath *pp, gboolean *def, gboolean priv)
@@ -1535,22 +1512,17 @@ get_string_with_default_from_pp_with_lang (ParsedPath *pp,
  * gnome_config_get_translated_string:
  * @path: A gnome configuration path to an item.
  *
- * Retrieves the value of a configuration item as a string appropriate for the
- * current language. The returned value should be freed with g_free() when no
- * longer needed.
- *
- * Returns: The value of the configuration item.
+ * Retrieves & returns the value of a configuration item as a string
+ * appropriate for the current language. The returned value should be
+ * g_free()'d when no longer needed.
  */
 /**
  * gnome_config_private_get_translated_string:
  * @path: A gnome configuration path to an item in the user-private namespace.
  *
- * Retrieves the value of a configuration item as a string appropriate for the
- * current language. The returned value should be freed with g_free() when no
- * longer needed.  The item is retrieved from the user's private configuration
- * storage area.
- *
- * Returns: The value of the configuration item.
+ * Retrieves & returns the value of a configuration item as a string appropriate for the current language. The returned value should be
+ * g_free()'d when no longer needed.
+ * The item is retrieved from the user's private configuration storage area.
  */
 /**
  * gnome_config_get_translated_string_with_default:
@@ -1558,12 +1530,8 @@ get_string_with_default_from_pp_with_lang (ParsedPath *pp,
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Retrieves the value of a configuration item as a string appropriate for the
- * current language. The returned value should be freed with g_free() when no
- * longer needed.
- *
- * Returns: The value of the configuration item or @def if the configuration
- * item does not exist.
+ * Retrieves & returns the value of a configuration item as a string appropriate for the current language. The returned value should be
+ * g_free()'d when no longer needed.
  */
 /**
  * gnome_config_private_get_translated_string_with_default:
@@ -1571,16 +1539,12 @@ get_string_with_default_from_pp_with_lang (ParsedPath *pp,
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Retrieves the value of a configuration item as a string appropriate for the
- * current language. The returned value should be freed with g_free() when no
- * longer needed.  The item is retrieved from the user's private configuration
- * storage area.
- *
- * Returns: The value of the configuration item or @def if the configuration
- * item does not exist.
+ * Retrieves & returns the value of a configuration item as a string appropriate for the current language. The returned value should be
+ * g_free()'d when no longer needed.
+ * The item is retrieved from the user's private configuration storage area.
  */
 char *
-gnome_config_get_translated_string_with_default_ (const char *path,
+_gnome_config_get_translated_string_with_default (const char *path,
 						  gboolean *def,
 						  gboolean priv)
 {
@@ -1646,20 +1610,18 @@ gnome_config_get_translated_string_with_default_ (const char *path,
  * gnome_config_get_string:
  * @path: A gnome configuration path to an item.
  *
- * Retrieves the value of a configuration item as a string. This value should
- * be freed with g_free() when no longer needed.
- *
- * Returns: The value of the configuration item as a string.
+ * Retrieves & returns the value of a configuration item as a string.
+ * The returned value should be
+ * g_free()'d when no longer needed.
  */
 /**
  * gnome_config_private_get_string:
  * @path: A gnome configuration path to an item in the user-private namespace.
  *
- * Retrieves the value of a configuration item from the user's private
- * configuration directory as a string. This value should be freed with
- * g_free() when no longer needed.
- *
- * Returns: The value of the configuration item as a string.
+ * Retrieves & returns the value of a configuration item as a
+ * string. The returned value should be g_free()'d when no longer
+ * needed.  The item is retrieved from the user's private
+ * configuration storage area.
  */
 /**
  * gnome_config_get_string_with_default:
@@ -1667,11 +1629,9 @@ gnome_config_get_translated_string_with_default_ (const char *path,
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Retrieves the value of a configuration item as a string. This value should
- * be freed with g_free() when no longer needed.
+ * Retrieves & returns the value of a configuration item as a string.
+ * The returned value should be g_free()'d when no longer needed.
  *
- * Returns: The value of the configuration item as a string, or @def if the
- * configuration key does not exist.
  */
 /**
  * gnome_config_private_get_string_with_default:
@@ -1679,15 +1639,14 @@ gnome_config_get_translated_string_with_default_ (const char *path,
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Retrieves the value of a configuration item from the user's private
- * configuration directory as a string. This value should be freed with
- * g_free() when no longer needed.
+ * Retrieves & returns the value of a configuration item as a string.
+ * The returned value should be g_free()'d when no longer needed.  The
+ * item is retrieved from the user's private configuration storage
+ * area.
  *
- * Returns: The value of the configuration item as a string, or @def if the
- * configuration key does not exist.
  */
 char *
-gnome_config_get_string_with_default_ (const char *path, gboolean *def,
+_gnome_config_get_string_with_default (const char *path, gboolean *def,
 				       gboolean priv)
 {
 	ParsedPath *pp;
@@ -1704,17 +1663,14 @@ gnome_config_get_string_with_default_ (const char *path, gboolean *def,
  * gnome_config_get_bool:
  * @path: A gnome configuration path to an item.
  *
- * Retrieves a boolean configuration value.
- *
- * Returns: The value of a configuration item.
+ * Retrieves & returns the value of a configuration item as a boolean.
  */
 /**
  * gnome_config_private_get_bool:
  * @path: A gnome configuration path to an item in the user-private namespace.
  *
- * Retrieves the item from the user's private configuration storage area.
- *
- * Returns: The value of a configuration item as a boolean.
+ * Retrieves & returns the value of a configuration item as a boolean.
+ * The item is retrieved from the user's private configuration storage area.
  */
 /**
  * gnome_config_get_bool_with_default:
@@ -1722,10 +1678,7 @@ gnome_config_get_string_with_default_ (const char *path, gboolean *def,
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Retrieves a boolean configuration value.
- *
- * Returns: The value of a configuration item, or @def if the
- * configuration item does not exist.
+ * Retrieves & returns the value of a configuration item as a boolean.
  */
 /**
  * gnome_config_private_get_bool_with_default:
@@ -1733,13 +1686,11 @@ gnome_config_get_string_with_default_ (const char *path, gboolean *def,
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Retrieves the item from the user's private configuration storage area.
- *
- * Returns: The value of a configuration item as a boolean, or @def if the
- * configuration item does not exist.
+ * Retrieves & returns the value of a configuration item as a boolean.
+ * The item is retrieved from the user's private configuration storage area.
  */
 gboolean
-gnome_config_get_bool_with_default_ (const char *path, gboolean *def,
+_gnome_config_get_bool_with_default (const char *path, gboolean *def,
 				     gboolean priv)
 {
 	ParsedPath *pp;
@@ -1760,7 +1711,7 @@ gnome_config_get_bool_with_default_ (const char *path, gboolean *def,
 		return 0;
 	}
 
-	if (g_ascii_tolower(*r) == 't' || g_ascii_tolower(*r) == 'y' || atoi(r)) {
+	if (tolower(*r) == 't' || tolower(*r) == 'y' || atoi(r)) {
 	  v = 1;
 	} else {
 	  /* If it's not true it has to be false :) */
@@ -1773,8 +1724,8 @@ gnome_config_get_bool_with_default_ (const char *path, gboolean *def,
 /**
  * gnome_config_make_vector:
  * @string: The stringified vector to decode into 'argcp' and 'argvp'
- * @argcp: Returns the number of elements in @string.
- * @argvp: Returns the array of strings found in @string.
+ * @argcp: Returns the number of elements in 'argvp'
+ * @argvp: Returns the array of strings found in 'rr'.
  *
  * Creates a new vector from a string as it stored in the config file,
  * breaks the string on spaces except if the space is escaped with a
@@ -1845,33 +1796,34 @@ gnome_config_make_vector (const char *string, int *argcp, char ***argvp)
 /**
  * gnome_config_get_vector:
  * @path: A gnome configuration path to an item.
- * @argcp: Number of elements in the vector.
- * @argvp: Vector of strings.
+ * @argcp: Number of elements in the vector
+ * @argvp: Vector of strings
  *
- * Retrieves the value of a configuration item as a string array.
- * The returned vector should be freed with g_free() when no longer needed.
+ * Retrieves & returns the value of a configuration item as a string array.
+ * The returned value should be
+ * g_free()'d when no longer needed.
  */
 /**
  * gnome_config_private_get_vector:
  * @path: A gnome configuration path to an item in the user-private namespace.
- * @argcp: Number of elements in the vector.
- * @argvp: Vector of strings.
+ * @argcp: Number of elements in the vector
+ * @argvp: Vector of strings
  *
- * Retrieves the value of a configuration item as a string array.
- * The returned vector should be freed with g_free() when no longer needed. The
- * configuration value is retrieved from the user's private configuration
- * storage area.
+ * Retrieves & returns the value of a configuration item as a
+ * string. The returned value should be g_free()'d when no longer
+ * needed.  The item is retrieved from the user's private
+ * configuration storage area.
  */
 /**
  * gnome_config_get_vector_with_default:
  * @path: A gnome configuration path to an item.
- * @argcp: Number of elements in the vector.
- * @argvp: Vector of strings.
+ * @argcp: Number of elements in the vector
+ * @argvp: Vector of strings
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Retrieves the value of a configuration item as a string array.
- * The returned vector should be freed with g_free() when no longer needed.
+ * Retrieves & returns the value of a configuration item as a string array.
+ * The returned value should be g_free()'d when no longer needed.
  *
  */
 /**
@@ -1882,13 +1834,14 @@ gnome_config_make_vector (const char *string, int *argcp, char ***argvp)
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Retrieves the value of a configuration item as a string array.
- * The returned vector should be freed with g_free() when no longer needed. The
- * configuration value is retrieved from the user's private configuration
- * storage area.
+ * Retrieves & returns the value of a configuration item as a string array.
+ * The returned value should be g_free()'d when no longer needed.  The
+ * item is retrieved from the user's private configuration storage
+ * area.
+ *
  */
 void
-gnome_config_get_vector_with_default_ (const char *path, int *argcp,
+_gnome_config_get_vector_with_default (const char *path, int *argcp,
 				       char ***argvp, gboolean *def, gboolean priv)
 {
 	ParsedPath *pp;
@@ -1912,24 +1865,15 @@ gnome_config_get_vector_with_default_ (const char *path, int *argcp,
 
 /**
  * gnome_config_set_translated_string:
- * @path: A gnome configuration path to a key.
- * @value: A string value to set.
+ * @path: a gnome configuration path to a key
+ * @value: a string value to set.
  * 
- * Stores the string value @value in the file/section/key defined
+ * Stores the string value @new_value in the file/section/key defined
  * by the @path on the proper section for the current language set by
  * by the user.
  */
-/**
- * gnome_config_private_set_translated_string:
- * @path: A gnome configuration path to a key.
- * @new_value: A string value to set.
- * 
- * Stores the string value @new_value in the file/section/key defined by the
- * @path on the proper section for the current language set by by the user.
- * The configuration value is stored in the user's private storage area.
- */
 void
-gnome_config_set_translated_string_ (const char *path, const char *value,
+_gnome_config_set_translated_string (const char *path, const char *value,
 				     gboolean priv)
 {
 	const GList *language_list;
@@ -1942,31 +1886,22 @@ gnome_config_set_translated_string_ (const char *path, const char *value,
 
 	if (lang && (strcmp (lang, "C") != 0)) {
 		tkey = g_strconcat (path, "[", lang, "]", NULL);
-		gnome_config_set_string_(tkey, value, priv);
+		_gnome_config_set_string(tkey, value, priv);
 		g_free (tkey);
 	} else
-		gnome_config_set_string_ (path, value, priv);
+		_gnome_config_set_string (path, value, priv);
 }
 
 /**
  * gnome_config_set_string:
- * @path: A gnome configuration path to a key.
- * @new_value: A string value to set.
+ * @path: a gnome configuration path to a key
+ * @new_value: a string value to set.
  *
  * Stores the string value @new_value in the file/section/key
- * defined by the @path.
- */
-/**
- * gnome_config_private_set_string:
- * @path: A gnome configuration path to a key.
- * @new_value: A string value to set.
- *
- * Stores the string value @new_value in the file/section/key
- * defined by the @path. The configuration value is stored in the user's
- * private storage area.
+ * defined by the @path
  */
 void
-gnome_config_set_string_ (const char *path, const char *new_value, gboolean priv)
+_gnome_config_set_string (const char *path, const char *new_value, gboolean priv)
 {
 	ParsedPath *pp;
 	const char *r;
@@ -1979,23 +1914,14 @@ gnome_config_set_string_ (const char *path, const char *new_value, gboolean priv
 
 /**
  * gnome_config_set_int:
- * @path: A gnome configuration path to a key.
- * @new_value: A int value to set.
+ * @path: a gnome configuration path to a key
+ * @new_value: a int value to set.
  *
  * Stores the integer value @new_value in the file/section/key
- * defined by the @path.
- */
-/**
- * gnome_config_private_set_int:
- * @path: A gnome configuration path to a key.
- * @new_value: A int value to set.
- *
- * Stores the integer value @new_value in the file/section/key
- * defined by the @path. The value is stored in the user's private
- * configuration storage area.
+ * defined by the @path
  */
 void
-gnome_config_set_int_ (const char *path, int new_value, gboolean priv)
+_gnome_config_set_int (const char *path, int new_value, gboolean priv)
 {
 	ParsedPath *pp;
 	char intbuf [40];
@@ -2010,23 +1936,14 @@ gnome_config_set_int_ (const char *path, int new_value, gboolean priv)
 
 /**
  * gnome_config_set_float:
- * @path: A gnome configuration path to a key.
- * @new_value: A double value to set.
+ * @path: a gnome configuration path to a key
+ * @new_value: a double value to set.
  *
  * Stores the double value @new_value in the file/section/key
- * defined by the @path.
- */
-/**
- * gnome_config_private_set_float:
- * @path: A gnome configuration path to a key.
- * @new_value: A double value to set.
- *
- * Stores the double value @new_value in the file/section/key
- * defined by the @path. The value is stored in the user's private
- * configuration storage area.
+ * defined by the @path
  */
 void
-gnome_config_set_float_ (const char *path, gdouble new_value, gboolean priv)
+_gnome_config_set_float (const char *path, gdouble new_value, gboolean priv)
 {
 	ParsedPath *pp;
 	char floatbuf [40];
@@ -2046,22 +1963,14 @@ gnome_config_set_float_ (const char *path, gdouble new_value, gboolean priv)
 
 /**
  * gnome_config_set_bool:
- * @path: A gnome configuration path to a key.
- * @new_value: A boolean value to set.
+ * @path: a gnome configuration path to a key
+ * @new_value: a boolean value to set
  *
  * Stores boolean value @new_value in the file/section/key defined by
  * @path.
  */
-/**
- * gnome_config_private_set_bool:
- * @path: A gnome configuration path to a key.
- * @new_value: A boolean value to set.
- *
- * Stores boolean value @new_value in the file/section/key defined by @path.
- * The value is stored in the user's private configuration storage area.
- */
 void
-gnome_config_set_bool_ (const char *path, gboolean new_value, gboolean priv)
+_gnome_config_set_bool (const char *path, gboolean new_value, gboolean priv)
 {
 	ParsedPath *pp;
 	const char *r;
@@ -2078,10 +1987,9 @@ gnome_config_set_bool_ (const char *path, gboolean new_value, gboolean priv)
  * @argv: An array of strings.
  *
  * This routine returns the the strings in the array contactenated by
- * spaces. The return value should be freed with g_free() when it is no longer
- * required.
+ * spaces.
  *
- * Returns: A string with the concatenation results.
+ * Returns: a g_malloc()ed string with the concatenation results.
  */
 char *
 gnome_config_assemble_vector (int argc, const char *const argv [])
@@ -2115,24 +2023,15 @@ gnome_config_assemble_vector (int argc, const char *const argv [])
 
 /**
  * gnome_config_set_vector:
- * @path: A gnome configuration path to a key.
- * @argc: The number of elements in @argv.
- * @argv: A string array holding the data to store.
+ * @path: a gnome configuration path to a key
+ * @argc: the number of elements in @argv
+ * @argv: a string array holding the data to store.
  *
  * Stores vector @argv in the file/section/key defined by
  * @path.
  */
-/**
- * gnome_config_private_set_vector:
- * @path: A gnome configuration path to a key.
- * @argc: The number of elements in @argv.
- * @argv: A string array holding the data to store.
- *
- * Stores vector @argv in the file/section/key defined by @path. The
- * configuration value is set in the user's private storage area.
- */
 void
-gnome_config_set_vector_ (const char *path, int argc,
+_gnome_config_set_vector (const char *path, int argc,
 			  const char *const argv[],
 			  gboolean priv)
 {
@@ -2148,7 +2047,7 @@ gnome_config_set_vector_ (const char *path, int argc,
 
 /**
  * gnome_config_push_prefix:
- * @path: A gnome configuration path prefix.
+ * @path: a gnome configuration path prefix
  *
  * @path is a prefix that will be prepended automatically to any
  * non-absolute configuration path in gnome config.
