@@ -27,7 +27,7 @@
 #include <config.h>
 #include <stdlib.h>
 
-#define GCONF_ENABLE_INTERNALS
+#define GCONF_ENABLE_INTERNALS 1
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 extern struct poptOption gconf_options[];
@@ -35,18 +35,15 @@ extern struct poptOption gconf_options[];
 #include "gnome-i18nP.h"
 
 #include <libgnome/libgnome.h>
-
 #include "gnome-gconf.h"
-#include "gnome-gconfP.h"
 
 /**
  * gnome_gconf_get_gnome_libs_settings_relative:
  * @subkey: key part below the gnome desktop settings directory
  *
  * Description:  Gets the full key name for a GNOME desktop specific
- * setting for a specific application. Those keys are used to store application-specific
- * configuration, for example the history of a GnomeEntry. This
- * config space should only be used by libraries.
+ * setting.  That is something that affects the whole desktop.  This
+ * space should only be used by the gnome library and core applications.
  *
  * Returns:  A newly allocated string
  **/
@@ -106,7 +103,7 @@ gnome_gconf_get_app_settings_relative (GnomeProgram *program, const gchar *subke
 }
 
 /**
- * gnome_gconf_lazy_init
+ * gnome_gconf_lazy_init:
  *
  * Description:  Internal libgnome/ui routine.  You never have
  * to do this from your code.  But all places in libgnome/ui
@@ -114,10 +111,9 @@ gnome_gconf_get_app_settings_relative (GnomeProgram *program, const gchar *subke
  * calls.
  **/
 void
-_gnome_gconf_lazy_init (void)
+gnome_gconf_lazy_init (void)
 {
-	/* Note this is the same as in libgnomeui/libgnomeui/gnome-gconf-ui.c,
-	 * keep this in sync (it's named gnomeui_gconf_lazy_init) */
+	char *argv [] = { "dummy", NULL };
         gchar *settings_dir;
 	GConfClient* client = NULL;
 	static gboolean initialized = FALSE;
@@ -127,11 +123,13 @@ _gnome_gconf_lazy_init (void)
 
 	initialized = TRUE;
 
+	gconf_init (1, argv, NULL);
+
         client = gconf_client_get_default ();
 
         gconf_client_add_dir (client,
-			      "/desktop/gnome",
-			      GCONF_CLIENT_PRELOAD_NONE, NULL);
+                             "/desktop/gnome",
+                             GCONF_CLIENT_PRELOAD_NONE, NULL);
 
         settings_dir = gnome_gconf_get_gnome_libs_settings_relative ("");
 
@@ -141,25 +139,14 @@ _gnome_gconf_lazy_init (void)
 			      GCONF_CLIENT_PRELOAD_NONE,
 			      NULL);
         g_free (settings_dir);
-
-        /* Leak the GConfClient reference, we want to keep
-         * the client alive forever.
-         */
 }
 
-/**
- * gnome_gconf_module_info_get
- *
- * An internal libgnome/ui routine. This will never be needed in public code.
- *
- * Returns: A #GnomeModuleInfo instance representing the GConf module.
- */
 const GnomeModuleInfo *
-_gnome_gconf_module_info_get (void)
+gnome_gconf_module_info_get (void)
 {
 	static GnomeModuleInfo module_info = {
 		"gnome-gconf",
-		gconf_version,
+		/* FIXME: get this from gconf somehow */"1.1.1",
 		NULL /* description */,
 		NULL /* requirements */,
 		NULL /* instance init */,
