@@ -34,4 +34,18 @@ gchar      *gnome_gconf_get_gnome_libs_settings_relative (const gchar *subkey);
 gchar      *gnome_gconf_get_app_settings_relative        (GnomeProgram *program,
 							  const gchar *subkey);
 
-#endif /* GNOME_GCONF_H */
+/* GNOME GConf module; basically what this does is
+   create a global GConfClient for a GNOME application.  libgnomeui
+   uses the default gconf client.
+ */
+
+/* These two methods are very very private to libgnome* only,
+ * do not use them (however they ARE exported since libgnomeui
+ * needs to use them) */
+void			gnome_gconf_lazy_init		(void);
+const GnomeModuleInfo *	gnome_gconf_module_info_get	(void);
+
+#endif
+
+
+
